==> thrio-0.4.2.tar.gz: android/src/main/kotlin/com/hellobike/flutter/thrio/navigator/RouteSettings.kt <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 Hellobike Group
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

package com.hellobike.flutter.thrio.navigator

data class RouteSettings(val url: String, val index: Int) {

    var params: Any? = null
    var animated: Boolean = true
    var isNested: Boolean = false

    fun toArguments(): Map<String, Any> = mutableMapOf(
            "url" to url,
            "index" to index,
            "animated" to animated,
            "isNested" to isNested
    ).also {
        if (params != null) {
            it["params"] =  params as Any
        }
    }

    companion object {
        @JvmStatic
        fun fromArguments(arguments: Map<String, Any>): RouteSettings {
            val url = arguments["url"] as String
            val index = if (arguments["index"] != null) arguments["index"] as Int else 0
            val params = arguments["params"]
            val animated = if (arguments["animated"] != null) arguments["animated"] as Boolean else false
            return RouteSettings(url, index).also {
                it.params = params
                it.animated = animated
            }
        }
    }
}

==> thrio-0.4.4.tar.gz: android/src/main/kotlin/com/hellobike/flutter/thrio/navigator/RouteSettings.kt <==
/**
 * The MIT License (MIT)
 *
 * Copyright (c) 2019 Hellobike Group
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
 * to deal in the Software without restriction, including without limitation
 * the rights to use, copy, modify, merge, publish, distribute, sublicense,
 * and/or sell copies of the Software, and to permit persons to whom the
 * Software is furnished to do so, subject to the following conditions:
 * The above copyright notice and this permission notice shall be included
 * in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
 * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

package com.hellobike.flutter.thrio.navigator

data class RouteSettings(val url: String, val index: Int) {

    var params: Any? = null
    var animated: Boolean = true
    var isNested: Boolean = false

    fun toArguments(): Map<String, Any> = mutableMapOf(
            "url" to url,
            "index" to index,
            "animated" to animated,
            "isNested" to isNested
    ).also {
        if (params != null) {
            it["params"] = params as Any
        }
    }

    companion object {
        @JvmStatic
        fun fromArguments(arguments: Map<String, Any>): RouteSettings? {
            if (arguments == null || !arguments.containsKey("url")) {
                return null
            }
            val url = arguments["url"] as String
            val index = if (arguments["index"] != null) arguments["index"] as Int else 0
            val params = arguments["params"]
            val animated = if (arguments["animated"] != null) arguments["animated"] as Boolean else false
            return RouteSettings(url, index).also {
                it.params = params
                it.animated = animated
            }
        }
    }
}
